@@ -1,5 +1,9 @@
 context("Plotting US maps")
 
+test_that("dependencies are verified", {
+  expect_package_error("ggplot2", plot_usmap())
+})
+
 library(proto)
 
 example_data <- data.frame(
