@@ -1,5 +1,12 @@
 context("Transforming coordinate data frames")
 
+test_that("dependencies are verified", {
+  expect_package_error("sf", usmap_transform(data.frame()))
+  expect_package_error("sp", usmap_transform(data.frame()))
+  expect_package_error("sf", usmap_crs())
+  expect_package_error("sp", usmap_crs())
+})
+
 test_that("data frame with AK and HI points is transformed", {
   data <- data.frame(
     lon = c(-74.01, -95.36, -118.24, -87.65, -134.42, -157.86),
